summaryrefslogtreecommitdiffstats
path: root/kolf/kcomboboxdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kolf/kcomboboxdialog.h')
-rw-r--r--kolf/kcomboboxdialog.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kolf/kcomboboxdialog.h b/kolf/kcomboboxdialog.h
index 28f3721f..91097f16 100644
--- a/kolf/kcomboboxdialog.h
+++ b/kolf/kcomboboxdialog.h
@@ -40,6 +40,7 @@ class KHistoryCombo;
class KComboBoxDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -51,7 +52,7 @@ public:
* @param _text Text of the label
* @param _value Initial value of the combobox
*/
- KComboBoxDialog( const TQString &_text, const TQStringList& _items, const TQString& _value = TQString::null, bool showDontAskAgain = false, TQWidget *parent = 0 );
+ KComboBoxDialog( const TQString &_text, const TQStringList& _items, const TQString& _value = TQString(), bool showDontAskAgain = false, TQWidget *tqparent = 0 );
virtual ~KComboBoxDialog();
/**
@@ -70,9 +71,9 @@ public:
* @param _text Text of the label
* @param _items Items in the combobox
* @param _value Initial value of the inputline
- * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use TQString::null to disable
+ * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use TQString() to disable
*/
- static TQString getItem( const TQString &_text, const TQStringList &_items, const TQString& _value = TQString::null, const TQString &dontAskAgainName = TQString::null, TQWidget *parent = 0 );
+ static TQString getItem( const TQString &_text, const TQStringList &_items, const TQString& _value = TQString(), const TQString &dontAskAgainName = TQString(), TQWidget *tqparent = 0 );
/**
* Static convenience function to get input from the user.
@@ -82,9 +83,9 @@ public:
* @param _text Text of the label
* @param _items Items in the combobox
* @param _value Initial value of the inputline
- * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use TQString::null to disable
+ * @param dontAskAgainName Name for saving whether the user doesn't want to be asked again; use TQString() to disable
*/
- static TQString getItem( const TQString &_text, const TQString &_caption, const TQStringList &_items, const TQString& _value = TQString::null, const TQString &dontAskAgainName = TQString::null, TQWidget *parent = 0 );
+ static TQString getItem( const TQString &_text, const TQString &_caption, const TQStringList &_items, const TQString& _value = TQString(), const TQString &dontAskAgainName = TQString(), TQWidget *tqparent = 0 );
/**
* Static convenience method.
@@ -95,14 +96,14 @@ public:
* @param _text Text of the label
* @param _value Initial value of the inputline
* @param ok Variable to store whether the user hit OK
* @param parent Parent widget for the dialog
* @param configName Name of the dialog for saving the completion and history
* @parma config KConfig for saving the completion and history
*/
static TQString getText(const TQString &_caption, const TQString &_text,
- const TQString &_value = TQString::null,
- bool *ok = 0, TQWidget *parent = 0,
- const TQString &configName = TQString::null,
+ const TQString &_value = TQString(),
+ bool *ok = 0, TQWidget *tqparent = 0,
+ const TQString &configName = TQString(),
KConfig *config = KGlobal::config());
protected:
@@ -95,14 +96,14 @@ public:
* @param _value Initial value of the inputline
* @param ok Variable to store whether the user hit OK
- * @param parent Parent widget for the dialog
+ * @param tqparent Parent widget for the dialog
* @param configName Name of the dialog for saving the completion and history
* @parma config KConfig for saving the completion and history